@@ -16,6 +16,7 @@ use App::cpm::Util qw(WIN32 determine_home maybe_abs);
 use App::cpm::Worker;
 use App::cpm::version;
 use App::cpm;
+use CPAN::Meta;
 use Config;
 use Cwd ();
 use File::Copy ();
@@ -85,6 +86,7 @@ sub parse_options {
         "test!" => sub { $self->{notest} = $_[1] ? 0 : 1 },
         "cpanfile=s" => sub { $self->{dependency_file} = { type => "cpanfile", path => $_[1] } },
         "cpmfile=s" => sub { $self->{dependency_file} = { type => "cpmfile", path => $_[1] } },
+        "metafile=s" => sub { $self->{dependency_file} = { type => "metafile", path => $_[1] } },
         "snapshot=s" => \($self->{snapshot}),
         "sudo" => \($self->{sudo}),
         "r|resolver=s@" => \@resolver,
@@ -259,7 +261,7 @@ sub cmd_version {
 
 sub cmd_install {
     my $self = shift;
-    die "Need arguments or cpm.yml/cpanfile\n" if !$self->{argv} && !$self->{dependency_file};
+    die "Need arguments or cpmfile/cpanfile/metafile\n" if !$self->{argv} && !$self->{dependency_file};
 
     local %ENV = %ENV;
 
@@ -485,13 +487,19 @@ sub initial_task {
 sub load_dependency_file {
     my $self = shift;
 
-    my $cpmfile;
-    if ($self->{dependency_file}{type} eq "cpmfile") {
-        $cpmfile = Module::cpmfile->load($self->{dependency_file}{path});
-    } else {
-        my $cpanfile = Module::CPANfile->load($self->{dependency_file}{path});
-        $cpmfile =  Module::cpmfile->from_cpanfile($cpanfile);
-    }
+    my $cpmfile = do {
+        my ($type, $path) = @{ $self->{dependency_file} }{qw(type path)};
+        warn "Loading requirements from $path...\n";
+        if ($type eq "cpmfile") {
+            Module::cpmfile->load($path);
+        } elsif ($type eq "cpanfile") {
+            Module::cpmfile->from_cpanfile(Module::CPANfile->load($path));
+        } elsif ($type eq "metafile") {
+            Module::cpmfile->from_cpanmeta(CPAN::Meta->load_file($path));
+        } else {
+            die;
+        }
+    };
     if (!$self->{mirror}) {
         my $mirrors = $cpmfile->{_mirrors} || [];
         if (@$mirrors) {
